using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace RSSMA_PULM_Example
{
    public partial class dialog : Form
    {
        string _strDoublePulseWidth = "1e-3", _strDoublePulseDelay = "1e-3";
        int _nTriggerMode = 0, _nTriggerSlope = 0, _nTriggerPolarity = 0;


        public dialog()
        {
            InitializeComponent();
        }

        private void dialog_Load(object sender, EventArgs e)
        {
        }
        
        private void ExitBTN_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void ApplyBTN_Click(object sender, EventArgs e)
        {
            rssma instrument;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
                instrument = new rssma(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);

                double dDoublePulseWidth = Convert.ToDouble(_strDoublePulseWidth);
                double dDoublePulseDelay = Convert.ToDouble(_strDoublePulseDelay);
                double dPulsePeriod = Decimal.ToDouble(_pulsePeriod.Value);
                double dPulseWidth = Decimal.ToDouble(_pulseWidth.Value);
                double dPulseDelay = Decimal.ToDouble(_pulseDelay.Value);

                instrument.confRFFreq(Decimal.ToDouble(RFFrequency.Value), 0.0, false, 0.0);
                instrument.confRFLevel(Decimal.ToDouble(RFLevel.Value), 0.0, 30.0, false, 0.0,
                                            rssmaConstants.OutputAmodeAuto,
                                            rssmaConstants.PowerLevelRclExclude);

                instrument.confPulm(_pulseState.Checked, rssmaConstants.PulmSourceInternal, rssmaConstants.PulmPolarityNormal,
                                          _pulseGeneratorState.Checked, Decimal.ToDouble(_pulsePeriod.Value), Decimal.ToDouble(_pulseWidth.Value), Decimal.ToDouble(_pulseDelay.Value), _doublePulse.Checked, dDoublePulseWidth,
                                          dDoublePulseDelay, _nTriggerMode);

                                                                                                       

                switch (_nTriggerMode)
                {
                    case 0: // Auto
                    case 1: // Ext Trigger
                        instrument.SetInstrumentTriggerInputSlope(_nTriggerSlope);
                        break;
                    case 2: // Ext Gated
                        instrument.SetInstrumentTriggerInputSlope(_nTriggerPolarity);
                        break;
                }

                instrument.SetOutputState(RFState.Checked);
            }
            catch (Exception ex)
            {
                String message;

                message = "Instrument Status Error: ";
                message += ex.Message;
                MessageBox.Show(message);
            }
            System.Windows.Forms.Cursor.Current = Cursors.Arrow;
            UseWaitCursor = false;
        }

        private void OnDoublePulse(object sender, EventArgs e)
        {
            DlgDoublePulse dlg = new DlgDoublePulse();

            dlg.DoublePulseWidth = _strDoublePulseWidth;
            dlg.DoublePulseDelay = _strDoublePulseDelay;

            if (dlg.ShowDialog() == DialogResult.OK)
            {
                _strDoublePulseWidth = dlg.DoublePulseWidth;
                _strDoublePulseDelay = dlg.DoublePulseDelay;
            }
        }

        private void OnTrigger(object sender, EventArgs e)
        {
            DlgTrigger dlg = new DlgTrigger();

            dlg.Mode = _nTriggerMode;
            dlg.Slope = _nTriggerSlope;
            dlg.Polarity = _nTriggerPolarity;

            if (dlg.ShowDialog() == DialogResult.OK)
            {
                _nTriggerMode = dlg.Mode;
                _nTriggerSlope = dlg.Slope;
                _nTriggerPolarity = dlg.Polarity;
            }
        }

        private void OnChangeDoublePulse(object sender, EventArgs e)
        {
            _buttonDoublePulse.Enabled = _doublePulse.Checked;
        }


        
    }
}